# <img src='https://0000.us/klatchat/app/files/neon_images/icons/neon_skill.png' card_color="#FF8600" width="50" style="vertical-align:bottom">Personal

## Summary

Skill used for introduction between the user and Neon.

## Description

Personal skill provides responses to questions about who Neon is.

## Examples
- Who are you?
- Who made you?
- When were you born?
- What is your email address?
- Where were you born?
- What are you?
- How are you?
- What is your name?
- Where are you?

## Contact Support

Use the [link](https://neongecko.com/ContactUs) or [submit an issue on GitHub](https://help.github.com/en/articles/creating-an-issue)

## Category
**Entertainment**
Daily
Information

## Credits
[Mycroft AI](https://github.com/MycroftAI)
[NeonDaniel](https://github.com/NeonDaniel)
[reginaneon](https://github.com/reginaneon)
